Counter

Struct Counter 

pub struct Counter { /* private fields */ }
The timeout condition is independent of time and is determined solely by the number of times timeout() is called.

Examples

use waiter_trait::{prelude::*, Counter};

let c = Counter::new(0);
let mut t = c.start();
assert!(t.timeout());
assert!(t.timeout());

let c = Counter::new(usize::MAX);
let mut t = c.start();
assert!(!t.timeout());
assert!(!t.timeout());

let c = Counter::new(2);
let mut t = c.start();
assert!(!t.timeout());
assert!(!t.timeout());
assert!(t.timeout());
assert!(t.timeout());

t.restart();
assert!(!t.timeout());
assert!(!t.timeout());
assert!(t.timeout());
assert!(t.timeout());

Implementations

Source

impl Counter

pub fn new(retry_times: usize) -> Self

  • retry_times: The number of calls to timeout() before it returns true.
    • If set to 0, timeout() always returns true
    • If set to usize::MAX, timeout() always returns false